@@ -40,9 +40,15 @@ from filelock import FileLock, Timeout
 from ansiblelint import cli
 from ansiblelint._mockings import _perform_mockings_cleanup
 from ansiblelint.app import get_app
-from ansiblelint.color import console, console_options, reconfigure, render_yaml
+from ansiblelint.color import (
+    console,
+    console_options,
+    console_stderr,
+    reconfigure,
+    render_yaml,
+)
 from ansiblelint.config import get_version_warning, options
-from ansiblelint.constants import EXIT_CONTROL_C_RC, LOCK_TIMEOUT_RC
+from ansiblelint.constants import EXIT_CONTROL_C_RC, GIT_CMD, LOCK_TIMEOUT_RC
 from ansiblelint.file_utils import abspath, cwd, normpath
 from ansiblelint.skip_utils import normalize_tag
 from ansiblelint.version import __version__
@@ -107,18 +113,18 @@ def initialize_options(arguments: list[str] | None = None) -> None:
     os.makedirs(options.cache_dir, exist_ok=True)
 
     options.cache_dir_lock = None
-    if not options.offline:
+    if not options.offline:  # pragma: no cover
         options.cache_dir_lock = FileLock(f"{options.cache_dir}/.lock")
         try:
             options.cache_dir_lock.acquire(timeout=180)
-        except Timeout:
+        except Timeout:  # pragma: no cover
             _logger.error(
                 "Timeout waiting for another instance of ansible-lint to release the lock."
             )
             sys.exit(LOCK_TIMEOUT_RC)
 
     # Avoid extra output noise from Ansible about using devel versions
-    if "ANSIBLE_DEVEL_WARNING" not in os.environ:
+    if "ANSIBLE_DEVEL_WARNING" not in os.environ:  # pragma: no branch
         os.environ["ANSIBLE_DEVEL_WARNING"] = "false"
 
 
@@ -135,13 +141,15 @@ def _do_list(rules: RulesCollection) -> int:
     if options.list_rules:
 
         _rule_format_map: dict[str, Callable[..., Any]] = {
-            "plain": rules_as_str,
-            "rich": rules_as_rich,
+            "brief": rules_as_str,
+            "full": rules_as_rich,
             "md": rules_as_md,
             "docs": rules_as_docs,
         }
 
-        console.print(_rule_format_map[options.format](rules), highlight=False)
+        console.print(
+            _rule_format_map.get(options.format, rules_as_str)(rules), highlight=False
+        )
         return 0
 
     if options.list_tags:
@@ -170,13 +178,23 @@ def _do_transform(result: LintResult, opts: Namespace) -> None:
     transformer.run()
 
 
+def support_banner() -> None:
+    """Display support banner when running on unsupported platform."""
+    if sys.version_info < (3, 9, 0):  # pragma: no cover
+        prefix = "::warning::" if "GITHUB_ACTION" in os.environ else "WARNING: "
+        console_stderr.print(
+            f"{prefix}ansible-lint is no longer tested under Python {sys.version_info.major}.{sys.version_info.minor} and will soon require 3.9. Do not report bugs for this version.",
+            style="bold red",
+        )
+
+
 # pylint: disable=too-many-branches,too-many-statements
 def main(argv: list[str] | None = None) -> int:  # noqa: C901
     """Linter CLI entry point."""
     # alter PATH if needed (venv support)
     path_inject()
 
-    if argv is None:
+    if argv is None:  # pragma: no cover
         argv = sys.argv
     initialize_options(argv[1:])
 
@@ -190,16 +208,16 @@ def main(argv: list[str] | None = None) -> int:  # noqa: C901
         msg = get_version_warning()
         if msg:
             console.print(msg)
+        support_banner()
         sys.exit(0)
+    else:
+        support_banner()
 
     initialize_logger(options.verbosity)
     _logger.debug("Options: %s", options)
     _logger.debug(os.getcwd())
 
     if not options.offline:
-        # refresh schemas must happen before loading rules
-        if "ansiblelint.schemas" in sys.modules:
-            raise RuntimeError("ansiblelint.schemas should not be loaded yet")
         # pylint: disable=import-outside-toplevel
         from ansiblelint.schemas import refresh_schemas
 
@@ -222,7 +240,7 @@ def main(argv: list[str] | None = None) -> int:  # noqa: C901
 
     app = get_app()
     if isinstance(options.tags, str):
-        options.tags = options.tags.split(",")
+        options.tags = options.tags.split(",")  # pragma: no cover
     result = _get_matches(rules, options)
 
     if options.write_list:
@@ -265,6 +283,9 @@ def main(argv: list[str] | None = None) -> int:  # noqa: C901
     if options.strict and result.matches:
         mark_as_success = False
 
+    # Remove skipped list items from the result
+    result.matches = [m for m in result.matches if m.tag not in app.options.skip_list]
+
     app.render_matches(result.matches)
 
     _perform_mockings_cleanup()
@@ -288,7 +309,7 @@ def _previous_revision() -> Iterator[None]:
     rel_exclude_paths = [normpath(p) for p in options.exclude_paths]
     options.exclude_paths = [abspath(p, worktree_dir) for p in rel_exclude_paths]
     revision = subprocess.run(
-        ["git", "rev-parse", "HEAD^1"],
+        [*GIT_CMD, "rev-parse", "HEAD^1"],
         check=True,
         text=True,
         stdout=subprocess.PIPE,
@@ -302,14 +323,14 @@ def _previous_revision() -> Iterator[None]:
     # Run check will fail if worktree_dir already exists
     # pylint: disable=subprocess-run-check
     subprocess.run(
-        ["git", "worktree", "add", "-f", worktree_dir],
+        [*GIT_CMD, "worktree", "add", "-f", worktree_dir],
         stdout=subprocess.DEVNULL,
         stderr=subprocess.DEVNULL,
     )
     try:
         with cwd(worktree_dir):
             subprocess.run(
-                ["git", "checkout", revision],
+                [*GIT_CMD, "checkout", revision],
                 stdout=subprocess.DEVNULL,
                 stderr=subprocess.DEVNULL,
                 check=True,
@@ -328,11 +349,11 @@ def _run_cli_entrypoint() -> None:
         sys.exit(main(sys.argv))
     except OSError as exc:
         # NOTE: Only "broken pipe" is acceptable to ignore
-        if exc.errno != errno.EPIPE:
+        if exc.errno != errno.EPIPE:  # pragma: no cover
             raise
-    except KeyboardInterrupt:
+    except KeyboardInterrupt:  # pragma: no cover
         sys.exit(EXIT_CONTROL_C_RC)
-    except RuntimeError as exc:
+    except RuntimeError as exc:  # pragma: no cover
         raise SystemExit(exc) from exc
 
 
@@ -349,10 +370,11 @@ def path_inject() -> None:
     # Expand ~ in PATH as it known to break many tools
     expanded = False
     for idx, path in enumerate(paths):
-        if "~" in path:
+        if "~" in path:  # pragma: no cover
             paths[idx] = os.path.expanduser(path)
             expanded = True
-    if expanded:
+    if expanded:  # pragma: no cover
+        # flake8: noqa: T201
         print(
             "WARNING: PATH altered to expand ~ in it. Read https://stackoverflow.com/a/44704799/99834 and correct your system configuration.",
             file=sys.stderr,
@@ -371,6 +393,7 @@ def path_inject() -> None:
         inject_paths.append(py_path)
 
     if inject_paths:
+        # flake8: noqa: T201
         print(
             f"WARNING: PATH altered to include {', '.join(inject_paths)} :: This is usually a sign of broken local setup, which can cause unexpected behaviors.",
             file=sys.stderr,
@@ -381,12 +404,13 @@ def path_inject() -> None:
     # We do know that finding ansible in PATH does not guarantee that it is
     # functioning or that is in fact the same version that was installed as
     # our dependency, but addressing this would be done by ansible-compat.
-    if not shutil.which("ansible"):
-        raise RuntimeError("Failed to find ansible executable in PATH")
+    for cmd in ("ansible", "git"):
+        if not shutil.which(cmd):
+            raise RuntimeError(f"Failed to find runtime dependency '{cmd}' in PATH")
 
 
 # Based on Ansible implementation
-def to_bool(value: Any) -> bool:
+def to_bool(value: Any) -> bool:  # pragma: no cover
     """Return a bool for the arg."""
     if value is None or isinstance(value, bool):
         return bool(value)
@@ -397,7 +421,7 @@ def to_bool(value: Any) -> bool:
     return False
 
 
-def should_do_markup(stream: TextIO = sys.stdout) -> bool:
+def should_do_markup(stream: TextIO = sys.stdout) -> bool:  # pragma: no cover
     """Decide about use of ANSI colors."""
     py_colors = None
 
