@@ -16,12 +16,14 @@ from ansiblelint.constants import (
     INVALID_CONFIG_RC,
 )
 from ansiblelint.file_utils import (
+    Lintable,
     abspath,
     expand_path_vars,
     guess_project_dir,
     normpath,
 )
-from ansiblelint.loaders import YAMLError, yaml_load_safe
+from ansiblelint.schemas.main import validate_file_schema
+from ansiblelint.yaml_utils import clean_json
 
 _logger = logging.getLogger(__name__)
 _PATH_VARS = [
@@ -64,28 +66,18 @@ def load_config(config_file: str) -> dict[Any, Any]:
         # a missing default config file should not trigger an error
         return {}
 
-    try:
-        with open(config_path, encoding="utf-8") as stream:
-            config = yaml_load_safe(stream)
-            # We want to allow passing /dev/null to disable config use
-            if config is None:
-                return {}
-            if not isinstance(config, dict):
-                _logger.error("Invalid configuration file %s", config_path)
-                sys.exit(INVALID_CONFIG_RC)
-    except YAMLError as exc:
-        _logger.error(exc)
+    config_lintable = Lintable(
+        config_path, kind="ansible-lint-config", base_kind="text/yaml"
+    )
+
+    for error in validate_file_schema(config_lintable):
+        _logger.error("Invalid configuration file %s. %s", config_path, error)
         sys.exit(INVALID_CONFIG_RC)
 
+    config = clean_json(config_lintable.data)
+    if not isinstance(config, dict):
+        raise RuntimeError("Schema failed to properly validate the config file.")
     config["config_file"] = config_path
-    # See https://github.com/ansible/ansible-lint/issues/1803
-    if isinstance(config, list):
-        _logger.error(
-            "Invalid configuration '%s', expected YAML mapping in the config file.",
-            config_path,
-        )
-        sys.exit(INVALID_CONFIG_RC)
-
     config_dir = os.path.dirname(config_path)
     expand_to_normalized_paths(config, config_dir)
 
@@ -232,7 +224,7 @@ def get_cli_parser() -> argparse.ArgumentParser:
         default=False,
         action="store_true",
         help="List all the rules. For listing rules only the following formats "
-        "for argument -f are supported: {plain, rich, md}",
+        "for argument -f are supported: {brief, full, md} with 'brief' as default.",
     )
     listing_group.add_argument(
         "-T",
@@ -246,10 +238,11 @@ def get_cli_parser() -> argparse.ArgumentParser:
         "-f",
         "--format",
         dest="format",
-        default="rich",
+        default=None,
         choices=[
-            "rich",
-            "plain",
+            "brief",
+            # "plain",
+            "full",
             "md",
             "json",
             "codeclimate",
@@ -260,6 +253,7 @@ def get_cli_parser() -> argparse.ArgumentParser:
         ],
         help="stdout formatting, json being an alias for codeclimate. (default: %(default)s)",
     )
+    parser.add_argument("--sarif-file", default=None, help="SARIF output file")
     parser.add_argument(
         "-q",
         dest="quiet",
@@ -288,8 +282,8 @@ def get_cli_parser() -> argparse.ArgumentParser:
         dest="progressive",
         default=False,
         action="store_true",
-        help="Return success if number of violations compared with"
-        "previous git commit has not increased. This feature works"
+        help="Return success if number of violations compared with "
+        "previous git commit has not increased. This feature works "
         "only in git repositories.",
     )
     parser.add_argument(
@@ -297,7 +291,7 @@ def get_cli_parser() -> argparse.ArgumentParser:
         dest="project_dir",
         default=".",
         help="Location of project/repository, autodetected based on location "
-        " of configuration file.",
+        "of configuration file.",
     )
     parser.add_argument(
         "-r",
@@ -371,7 +365,8 @@ def get_cli_parser() -> argparse.ArgumentParser:
         dest="skip_list",
         default=[],
         action="append",
-        help="only check rules whose id/tags do not " "match these values",
+        help="only check rules whose id/tags do not match these values. \
+            e.g: --skip-list=name,run-once",
     )
     parser.add_argument(
         "-w",
@@ -423,7 +418,7 @@ def get_cli_parser() -> argparse.ArgumentParser:
         dest="offline",
         action="store_const",
         const=True,
-        help="Disable installation of requirements.yml",
+        help="Disable installation of requirements.yml and schema refreshing",
     )
     parser.add_argument(
         "--version",
@@ -433,8 +428,7 @@ def get_cli_parser() -> argparse.ArgumentParser:
         dest="lintables",
         nargs="*",
         action="extend",
-        help="One or more files or paths. When missing it will "
-        " enable auto-detection mode.",
+        help="One or more files or paths. When missing it will enable auto-detection mode.",
     )
 
     return parser
@@ -470,6 +464,7 @@ def merge_config(file_config: dict[Any, Any], cli_config: Namespace) -> Namespac
         "loop_var_prefix": None,
         "project_dir": ".",
         "profile": None,
+        "sarif_file": None,
     }
 
     if not file_config:
@@ -532,10 +527,16 @@ def get_config(arguments: list[str]) -> Namespace:
     options = parser.parse_args(arguments)
 
     # docs is not document, being used for internal documentation building
-    if options.list_rules and options.format not in ["plain", "rich", "md", "docs"]:
+    if options.list_rules and options.format not in [
+        None,
+        "brief",
+        "full",
+        "md",
+        "docs",
+    ]:
         parser.error(
             f"argument -f: invalid choice: '{options.format}'. "
-            f"In combination with argument -L only 'plain', "
+            f"In combination with argument -L only 'brief', "
             f"'rich' or 'md' are supported with -f."
         )
 
