@@ -4,7 +4,6 @@ from __future__ import annotations
 import json
 import logging
 import os
-import re
 import sys
 import time
 import urllib.request
@@ -35,6 +34,7 @@ DEFAULT_WARN_LIST = [
     "jinja[spacing]",  # warning until we resolve all reported false-positives
     "name[casing]",
     "name[play]",
+    "name[prefix]",
     "role-name",
     "warning[empty-playbook]",  # because ansible considers it warning only
     "role-name[path]",  # too new
@@ -56,6 +56,7 @@ DEFAULT_KINDS = [
     {"galaxy": "**/galaxy.yml"},  # Galaxy collection meta
     {"reno": "**/releasenotes/*/*.{yaml,yml}"},  # reno release notes
     {"tasks": "**/tasks/**/*.{yaml,yml}"},
+    {"rulebook": "**/rulebooks/*.{yml,yaml"},
     {"playbook": "**/playbooks/*.{yml,yaml}"},
     {"playbook": "**/*playbook*.{yml,yaml}"},
     {"role": "**/roles/*/"},
@@ -73,6 +74,7 @@ DEFAULT_KINDS = [
     {"requirements": "**/requirements.{yaml,yml}"},  # v2 and v1
     {"playbook": "**/molecule/*/*.{yaml,yml}"},  # molecule playbooks
     {"yaml": "**/{.ansible-lint,.yamllint}"},
+    {"changelog": "**/changelogs/changelog.yaml"},
     {"yaml": "**/*.{yaml,yml}"},
     {"yaml": "**/.*.{yaml,yml}"},
 ]
@@ -105,7 +107,7 @@ options = Namespace(
     cwd=".",
     display_relative_path=True,
     exclude_paths=[],
-    format="rich",
+    format="brief",
     lintables=[],
     list_rules=False,
     list_tags=False,
@@ -123,6 +125,7 @@ options = Namespace(
     mock_roles=[],
     loop_var_prefix=None,
     only_builtins_allow_collections=[],
+    only_builtins_allow_modules=[],
     var_naming_pattern=None,
     offline=False,
     project_dir=".",  # default should be valid folder (do not use None here)
@@ -132,6 +135,8 @@ options = Namespace(
     strict=False,
     rules={},  # Placeholder to set and keep configurations for each rule.
     profile=None,
+    task_name_prefix="{stem} | ",
+    sarif_file=None,
 )
 
 # Used to store detected tag deprecations
@@ -144,7 +149,7 @@ collection_list: list[str] = []
 def get_rule_config(rule_id: str) -> dict[str, Any]:
     """Get configurations for the rule ``rule_id``."""
     rule_config = options.rules.get(rule_id, {})
-    if not isinstance(rule_config, dict):
+    if not isinstance(rule_config, dict):  # pragma: no branch
         raise RuntimeError(f"Invalid rule config for {rule_id}: {rule_config}")
     return rule_config
 
@@ -153,27 +158,15 @@ def get_rule_config(rule_id: str) -> dict[str, Any]:
 def ansible_collections_path() -> str:
     """Return collection path variable for current version of Ansible."""
     # respect Ansible behavior, which is to load old name if present
-    for env_var in ["ANSIBLE_COLLECTIONS_PATHS", "ANSIBLE_COLLECTIONS_PATH"]:
+    for env_var in [
+        "ANSIBLE_COLLECTIONS_PATHS",
+        "ANSIBLE_COLLECTIONS_PATH",
+    ]:  # pragma: no cover
         if env_var in os.environ:
             return env_var
     return "ANSIBLE_COLLECTIONS_PATH"
 
 
-def parse_ansible_version(stdout: str) -> tuple[str, str | None]:
-    """Parse output of 'ansible --version'."""
-    # Ansible can produce extra output before displaying version in debug mode.
-
-    # ansible-core 2.11+: 'ansible [core 2.11.3]'
-    match = re.search(r"^ansible \[(?:core|base) ([^\]]+)\]", stdout, re.MULTILINE)
-    if match:
-        return match.group(1), None
-    # ansible-base 2.10 and Ansible 2.9: 'ansible 2.x.y'
-    match = re.search(r"^ansible ([^\s]+)", stdout, re.MULTILINE)
-    if match:
-        return match.group(1), None
-    return "", f"FATAL: Unable parse ansible cli version: {stdout}"
-
-
 def in_venv() -> bool:
     """Determine whether Python is running from a venv."""
     if hasattr(sys, "real_prefix") or os.environ.get("CONDA_EXE", None) is not None:
@@ -232,14 +225,14 @@ def guess_install_method() -> str:
 def get_version_warning() -> str:
     """Display warning if current version is outdated."""
     # 0.1dev1 is special fallback version
-    if __version__ == "0.1.dev1":
+    if __version__ == "0.1.dev1":  # pragma: no cover
         return ""
 
     msg = ""
     data = {}
     current_version = Version(__version__)
 
-    if not os.path.exists(CACHE_DIR):
+    if not os.path.exists(CACHE_DIR):  # pragma: no cover
         os.makedirs(CACHE_DIR)
     cache_file = f"{CACHE_DIR}/latest.json"
     refresh = True
@@ -259,7 +252,7 @@ def get_version_warning() -> str:
                 data = json.load(url)
                 with open(cache_file, "w", encoding="utf-8") as f:
                     json.dump(data, f)
-        except (URLError, HTTPError) as exc:
+        except (URLError, HTTPError) as exc:  # pragma: no cover
             _logger.debug(
                 "Unable to fetch latest version from %s due to: %s", release_url, exc
             )
