@@ -121,8 +121,16 @@ def ansible_template(
     # pylint: disable=unused-variable
     for i in range(3):
         try:
+            kwargs["disable_lookups"] = True
             return templar.template(varname, **kwargs)
         except AnsibleError as exc:
+            if (
+                "was found, however lookups were disabled from templating"
+                in exc.message
+            ):
+                # ansible core does an early exit when disable_lookup=True but
+                # this happens after the jinja2 syntax already passed.
+                break
             if (
                 exc.message.startswith("template error while templating string:")
                 and "'" in exc.message
@@ -292,7 +300,7 @@ def play_children(
             v = template(
                 os.path.abspath(basedir),
                 v,
-                dict(playbook_dir=PLAYBOOK_DIR or os.path.abspath(basedir)),
+                {"playbook_dir": PLAYBOOK_DIR or os.path.abspath(basedir)},
                 fail_on_undefined=False,
             )
             return delegate_map[k](basedir, k, v, parent_type)
@@ -307,7 +315,7 @@ def _include_children(
         v = v["file"]
 
     # we cannot really parse any jinja2 in includes, so we ignore them
-    if "{{" in v:
+    if "{{" in v:  # pragma: no branch
         return []
 
     if "import_playbook" in k and COLLECTION_PLAY_RE.match(v):
@@ -402,7 +410,7 @@ def _get_task_handler_children_for_tasks_or_playbooks(
         with contextlib.suppress(KeyError):
 
             # ignore empty tasks
-            if not task_handler:
+            if not task_handler:  # pragma: no branch
                 continue
 
             file_name = task_handler[task_handler_key]
@@ -440,6 +448,9 @@ def _roles_children(
 ) -> list[Lintable]:
     # pylint: disable=unused-argument # parent_type)
     results: list[Lintable] = []
+    if not v:
+        # typing does not prevent junk from being passed in
+        return results
     for role in v:
         if isinstance(role, dict):
             if "role" in role or "name" in role:
@@ -478,12 +489,12 @@ def _rolepath(basedir: str, role: str) -> str | None:
 
     possible_paths.append(path_dwim(basedir, ""))
 
-    for path_option in possible_paths:
+    for path_option in possible_paths:  # pragma: no branch
         if os.path.isdir(path_option):
             role_path = path_option
             break
 
-    if role_path:
+    if role_path:  # pragma: no branch
         add_all_plugin_dirs(role_path)
 
     return role_path
@@ -494,7 +505,7 @@ def _look_for_role_files(
 ) -> list[Lintable]:
     # pylint: disable=unused-argument # main
     role_path = _rolepath(basedir, role)
-    if not role_path:
+    if not role_path:  # pragma: no branch
         return []
 
     results = []
@@ -512,7 +523,7 @@ def _look_for_role_files(
 
 def _kv_to_dict(v: str) -> dict[str, Any]:
     (command, args, kwargs) = tokenize(v)
-    return dict(__ansible_module__=command, __ansible_arguments__=args, **kwargs)
+    return {"__ansible_module__": command, "__ansible_arguments__": args, **kwargs}
 
 
 def _sanitize_task(task: dict[str, Any]) -> dict[str, Any]:
@@ -553,10 +564,10 @@ def normalize_task_v2(task: dict[str, Any]) -> dict[str, Any]:
     if is_nested_task(task):
         _extract_ansible_parsed_keys_from_task(result, task, ansible_parsed_keys)
         # Add dummy action for block/always/rescue statements
-        result["action"] = dict(
-            __ansible_module__="block/always/rescue",
-            __ansible_module_original__="block/always/rescue",
-        )
+        result["action"] = {
+            "__ansible_module__": "block/always/rescue",
+            "__ansible_module_original__": "block/always/rescue",
+        }
 
         return result
 
@@ -593,9 +604,10 @@ def normalize_task_v2(task: dict[str, Any]) -> dict[str, Any]:
     # the opposite. Mainly we currently consider normalized the module listing
     # used by `ansible-doc -t module -l 2>/dev/null`
     action = removeprefix(action, "ansible.builtin.")
-    result["action"] = dict(
-        __ansible_module__=action, __ansible_module_original__=action_unnormalized
-    )
+    result["action"] = {
+        "__ansible_module__": action,
+        "__ansible_module_original__": action_unnormalized,
+    }
 
     if "_raw_params" in arguments:
         # Doing a split here is really bad as it would break jinja2 templating
@@ -834,14 +846,6 @@ def get_lintables(
     if args:
         for arg in args:
             lintable = Lintable(arg)
-            if lintable.kind in ("yaml", None):
-                _logger.warning(
-                    "Overriding detected file kind '%s' with 'playbook' "
-                    "for given positional argument: %s",
-                    lintable.kind,
-                    arg,
-                )
-                lintable = Lintable(arg, kind="playbook")
             lintables.append(lintable)
     else:
 
@@ -880,7 +884,7 @@ def _extend_with_roles(lintables: list[Lintable]) -> None:
             role = lintable.path
             while role.parent.name != "roles" and role.name:
                 role = role.parent
-            if role.exists and not role.is_file():
+            if role.exists() and not role.is_file():
                 lintable = Lintable(role, kind="role")
                 if lintable not in lintables:
                     _logger.debug("Added role: %s", lintable)
